# 🧾 Changelog — monstrelib

Ce fichier suit les changements apportés à chaque version de `monstrelib`.

## [v0.3.0] - 2024-04-19
### Ajouté
- Fonction `subtract(a, b)`
- Pull Request complète avec review et correction

### Corrigé
- `subtract()` faisait une addition au lieu d'une soustraction

## [v0.2.0] - 2024-04-19
### Modifié
- Ajout d’un `print` dans la fonction `add()` pour affichage du calcul

## [v0.1.0] - 2024-04-19
### Créé
- Fonction `add(a, b)`
- Structure initiale du package avec `pyproject.toml`
